@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 
 '''openstack Apport interface
 
@@ -30,5 +30,5 @@ def add_info(report,ui):
 
 		attach_related_packages(report,
 				      ['python-nova', 'nova-common', 'nova-compute', 'nova-scheduler',
-					'nova-volume', 'nova-api', 'nova-network',
+					'nova-volume', 'nova-api',
 					'nova-doc', 'nova-cert'])
